@@ -20,7 +20,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION $STRING_VERSION);
-$VERSION        = '2.071_000';
+$VERSION        = '2.071_001';
 $STRING_VERSION = $VERSION;
 ## no critic(BuiltinFunctions::ProhibitStringyEval)
 $VERSION = eval $VERSION;
@@ -516,8 +516,7 @@ sub Marpa::R2::Scanless::G::_hash_to_runtime {
             or not $g1_thin->symbol_is_accessible($g1_symbol_id) )
         {
             Marpa::R2::exception(
-                q{A G0 lexeme is not accessible from the G1 start symbol: },
-                $thick_g1_grammar->symbol_in_display_form($g1_symbol_id)
+                "A G0 lexeme is not accessible from the G1 start symbol: $lexeme_name"
             );
         } ## end if ( not defined $g1_symbol_id or not $g1_thin...)
         my $lex_symbol_id = $lex_tracer->symbol_by_name($lexeme_name);
@@ -2006,6 +2005,12 @@ sub Marpa::R2::Scanless::G::thick_g1_grammar {
     return $slg->[Marpa::R2::Inner::Scanless::G::THICK_G1_GRAMMAR];
 }
 
+sub Marpa::R2::Scanless::R::thick_g1_grammar {
+    my ($slr) = @_;
+    my $slg = $slr->[Marpa::R2::Inner::Scanless::R::GRAMMAR];
+    return $slg->[Marpa::R2::Inner::Scanless::G::THICK_G1_GRAMMAR];
+}
+
 sub Marpa::R2::Scanless::R::thick_g1_recce {
     my ($slr) = @_;
     return $slr->[Marpa::R2::Inner::Scanless::R::THICK_G1_RECCE];
